from .APIResponse import APIResponse
from pyrezfix.models.Mixin import Player as PlayerMixin
class Friend(APIResponse, PlayerMixin):
    def __init__(self, **kwargs):
        APIResponse.__init__(self, **kwargs)
        PlayerMixin.__init__(self, **kwargs)
        self.accountId = kwargs.get("account_id", 0) or 0
        self.avatarURL = kwargs.get("avatar_url", '') or ''
